@@ -16,6 +16,8 @@ from .iresource import IResource
 from .irequest import IRequest
 from .nullbackoff import NullBackoff
 from .nullcredential import NullCredential
+from .ratelimited import RateLimited
+from .serverdoesnotexist import ServerDoesNotExist
 
 
 __all__: list[str] = [
@@ -29,4 +31,6 @@ __all__: list[str] = [
     'IRequest',
     'NullBackoff',
     'NullCredential',
+    'RateLimited',
+    'ServerDoesNotExist'
 ]
\ No newline at end of file
